Clojure only.

com.walmartlabs.lacinia.parser.docs

Parsing of a Markdown file for purposes of attaching documentation to a schema.

Parsing of a Markdown file for purposes of attaching documentation to a schema.
raw docstring

parse-docsclj

(parse-docs input)

Parses an input document. Returns a map who keys are the keyword versions of headers, and whose values are the (trimmed) content immediately beneath that header.

The result is a documentation map that can be provided to [[inject-descriptions]].

Parses an input document.  Returns a map who keys are the keyword versions of headers, and whose values
are the (trimmed) content immediately beneath that header.

The result is a documentation map that can be provided to [[inject-descriptions]].
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries